@@ -715,12 +715,17 @@ NULL, /* regex_ok_regex_c_1 322 */
 /*
  * renderopt.c
  */
+#ifdef WAVE_GTK_UNIX_PRINT
+NULL, /* gprs */
+NULL, /* gps */
+NULL, /* gp_tfn */
+#endif
 0, /* is_active_renderopt_c_3 323 */
 0, /* window_renderopt_c_6 324 */
 NULL, /* filesel_print_pdf_renderopt_c_1 */
 NULL, /* filesel_print_ps_renderopt_c_1 325 */
 NULL, /* filesel_print_mif_renderopt_c_1 326 */
-{0,0,0}, /* target_mutex_renderopt_c_1 328 */
+{0,0,0,0}, /* target_mutex_renderopt_c_1 328 */
 {0,0,0,0,0}, /* page_mutex_renderopt_c_1 330 */
 {0,0,0}, /* render_mutex_renderopt_c_1 332 */
 0, /* page_size_type_renderopt_c_1 333 */
@@ -1032,6 +1037,7 @@ NULL, /* ttrans_filter */
 NULL, /* fcurr_ttranslate_c_1 */
 NULL, /* window_ttranslate_c_5 */
 NULL, /* clist_ttranslate_c_2 */
+NULL, /* ttranslate_args */
 
 
 /*
@@ -1208,6 +1214,7 @@ NULL, /* mvlfacs_vzt_c_3 587 */
 /*
  * wavewindow.c
  */
+1, /* alt_wheel_mode */
 0, /* use_scrollwheel_as_y */
 0, /* enable_slider_zoom */
 0, /* m1x_wavewindow_c_1 589 */
@@ -1508,6 +1515,9 @@ void reload_into_new_context_2(void)
 
  logbox_reload();
 
+ /* kill any pending splash screens (e.g., from Tcl "wish") */
+ splash_button_press_event(NULL, NULL);
+
  /* fix problem where ungrab doesn't occur if button pressed + simultaneous reload accelerator key occurs */
  if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
 
@@ -1766,6 +1776,7 @@ void reload_into_new_context_2(void)
  new_globals->do_hier_compress = GLOBALS->do_hier_compress;
  new_globals->do_initial_zoom_fit = GLOBALS->do_initial_zoom_fit;
  new_globals->do_resize_signals = GLOBALS->do_resize_signals;
+ new_globals->alt_wheel_mode = GLOBALS->alt_wheel_mode;
  new_globals->initial_signal_window_width = GLOBALS->initial_signal_window_width;
  new_globals->enable_fast_exit = GLOBALS->enable_fast_exit;
  new_globals->enable_ghost_marker = GLOBALS->enable_ghost_marker;
@@ -1829,6 +1840,9 @@ void reload_into_new_context_2(void)
  strcpy2_into_new_context(new_globals, &new_globals->pFileChooseFilterName, &GLOBALS->pFileChooseFilterName);
 #endif
 
+ /* ttranslate.c */
+ strcpy2_into_new_context(new_globals, &new_globals->ttranslate_args, &GLOBALS->ttranslate_args);
+
  /* vlist.c */
  if(GLOBALS->vlist_handle)
 	{
@@ -1868,6 +1882,13 @@ void reload_into_new_context_2(void)
  strcpy2_into_new_context(new_globals, &new_globals->fcurr_translate_c_2, &GLOBALS->fcurr_translate_c_2);
  
 
+ /* renderopt.c */
+#ifdef WAVE_GTK_UNIX_PRINT
+ new_globals->gprs = GLOBALS->gprs;
+ new_globals->gps = GLOBALS->gps;
+#endif
+
+
  /* status.c */
  new_globals->text_status_c_2 = GLOBALS->text_status_c_2;
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
@@ -2627,6 +2648,7 @@ switch(type)
 							GLOBALS->do_zoom_center = g_old->do_zoom_center;
 							GLOBALS->use_roundcaps = g_old->use_roundcaps;
 							GLOBALS->do_resize_signals = g_old->do_resize_signals;
+							GLOBALS->alt_wheel_mode = g_old->alt_wheel_mode;
 							GLOBALS->initial_signal_window_width = g_old->initial_signal_window_width;
 							GLOBALS->use_full_precision = g_old->use_full_precision;
 							GLOBALS->show_base = g_old->show_base;
