@@ -101,6 +101,7 @@ GLOBALS->constant_marker_update = g_old->constant_marker_update;
 GLOBALS->do_zoom_center = g_old->do_zoom_center;
 GLOBALS->use_roundcaps = g_old->use_roundcaps;
 GLOBALS->do_resize_signals = g_old->do_resize_signals;
+GLOBALS->alt_wheel_mode = g_old->alt_wheel_mode;
 GLOBALS->initial_signal_window_width = g_old->initial_signal_window_width;
 GLOBALS->scale_to_time_dimension = g_old->scale_to_time_dimension;
 GLOBALS->use_full_precision = g_old->use_full_precision;
@@ -421,6 +422,7 @@ GtkWidget *panedwindow;
 GtkWidget *dummy1, *dummy2;
 GtkWidget *toolhandle=NULL;
 int tcl_interpreter_needs_making = 0;
+struct Global *old_g = NULL;
 
 int splash_disable_rc_override = 0;
 int mainwindow_already_built;
@@ -431,6 +433,7 @@ GdkPixbuf *dock_pb;
 WAVE_LOCALE_FIX
 
 /* Initialize the GLOBALS structure for the first time... */ 
+
 if(!GLOBALS)
 	{
 	set_GLOBALS(initialize_globals());
@@ -441,7 +444,7 @@ if(!GLOBALS)
 	}
 	else
 	{
-	struct Global *old_g = GLOBALS;
+	old_g = GLOBALS;
 
 	set_GLOBALS(initialize_globals());
 
@@ -543,6 +546,7 @@ if(!GLOBALS)
 	GLOBALS->disable_tooltips = old_g->disable_tooltips;
 	GLOBALS->do_initial_zoom_fit = old_g->do_initial_zoom_fit;
 	GLOBALS->do_resize_signals = old_g->do_resize_signals;
+	GLOBALS->alt_wheel_mode = old_g->alt_wheel_mode;
 	GLOBALS->initial_signal_window_width = old_g->initial_signal_window_width;
 	GLOBALS->scale_to_time_dimension = old_g->scale_to_time_dimension;
 	GLOBALS->enable_fast_exit = old_g->enable_fast_exit;
@@ -606,6 +610,12 @@ if(!GLOBALS)
 
 	GLOBALS->missing_file_toolbar = old_g->missing_file_toolbar;
 
+	GLOBALS->analog_redraw_skip_count = old_g->analog_redraw_skip_count;
+	GLOBALS->context_tabposition = old_g->context_tabposition;
+	GLOBALS->disable_empty_gui =  old_g->disable_empty_gui;
+	GLOBALS->make_vcd_save_file = old_g->make_vcd_save_file;
+	GLOBALS->strace_repeat_count = old_g->strace_repeat_count;
+
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_logfile, &old_g->fontname_logfile);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_signals, &old_g->fontname_signals); 
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_waves, &old_g->fontname_waves);
@@ -1125,7 +1135,11 @@ if((!GLOBALS->loaded_file_name) && wname)
 	}
 
 
-read_rc_file(override_rc);
+if(!old_g) /* copy all variables earlier when old_g is set */
+	{
+	read_rc_file(override_rc);
+	}
+
 GLOBALS->splash_disable |= splash_disable_rc_override;
 
 if(!GLOBALS->loaded_file_name)
