@@ -194,6 +194,9 @@ ps_header (pr_context * prc)
   fprintf (prc->handle,
 	   "%%!PS-Adobe-2.0 EPSF-1.2\n"
 	   "%%%%BoundingBox: %d %d %d %d\n"
+	   "%%%%Pages: 1\n"
+	   "%%%%EndComments\n"
+	   "%%%%Page: (1) 1\n"
 	   "/box { %% stack: _x1 _y1 x2 y2\n"
 	   "\tnewpath\n"
 	   "\t2 copy moveto %% x2 y2\n"
@@ -2131,10 +2134,38 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 	_x1 = GLOBALS->wavewidth;
 
       /* draw trans */
-      type =
-	(!(h->flags & (HIST_REAL | HIST_STRING))) ? vtype (t,
-							   h->v.
-							   h_vector) : AN_0;
+      if(!(h->flags&(HIST_REAL|HIST_STRING)))
+        {
+        type = vtype(t,h->v.h_vector);
+        }
+        else
+        {
+        /* s\000 ID is special "z" case */
+        type = AN_0;         
+
+        if(h->flags&HIST_STRING)                 
+                {
+                if(h->v.h_vector)
+                        {
+                        if(!h->v.h_vector[0])
+                                {
+                                type = AN_Z;                  
+                                }
+                        else
+                                {
+                                if(!strcmp(h->v.h_vector, "UNDEF")) 
+                                        {
+                                        type = AN_X;
+                                        }
+                                }
+                        }
+                        else
+                        {
+                        type = AN_X;
+                        }
+                }   
+        }       
+      /* type = !(h->flags & (HIST_REAL | HIST_STRING))) ? vtype (t, h->v.h_vector) : AN_0; */
       if (_x0 > -1)
 	{
 	  if (GLOBALS->use_roundcaps)
