@@ -15,6 +15,11 @@
 #include "debug.h"
 #include "pixmaps.h"
 
+#ifdef MAC_INTEGRATION
+
+#include <cocoa_misc.h>
+
+#else
 
 static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
@@ -33,14 +38,17 @@ static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
   GLOBALS->window_simplereq_c_9 = NULL;
   if(GLOBALS->cleanup)GLOBALS->cleanup(NULL,NULL);
 }
+#endif
 
 void simplereqbox(char *title, int width, char *default_text,
 	char *oktext, char *canceltext, GtkSignalFunc func, int is_alert)
 {
+#ifndef MAC_INTEGRATION
     GtkWidget *vbox, *hbox;
     GtkWidget *button1, *button2;
     GtkWidget *label, *separator;
     GtkWidget *pixmapwid1;
+#endif
 
     if(GLOBALS->window_simplereq_c_9) return; /* only should happen with GtkPlug */
 
@@ -55,6 +63,21 @@ void simplereqbox(char *title, int width, char *default_text,
 	return;
 	}
 
+#ifdef MAC_INTEGRATION
+    /* requester is modal so it will block */
+    switch(gtk_simplereqbox_req_bridge(title, default_text, oktext, canceltext, is_alert))
+	{
+	case 1:	if(GLOBALS->cleanup)GLOBALS->cleanup(NULL,(gpointer)1);
+		break;
+
+	case 2:	if(GLOBALS->cleanup)GLOBALS->cleanup(NULL,NULL);
+		break;
+
+	default:
+		break;
+	}
+#else
+
     /* create a new modal window */
     GLOBALS->window_simplereq_c_9 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
     install_focus_cb(GLOBALS->window_simplereq_c_9, ((char *)&GLOBALS->window_simplereq_c_9) - ((char *)GLOBALS));
@@ -112,5 +135,6 @@ void simplereqbox(char *title, int width, char *default_text,
 
     gtk_widget_show(GLOBALS->window_simplereq_c_9);
     wave_gtk_grab_add(GLOBALS->window_simplereq_c_9);
+#endif
 }
 
